# -*- coding: UTF-8 -*-
# Copyright (C) 2009 Hervé Cauwelier <herve@oursours.net>
# Copyright (C) 2009, 2012 J. David Ibáñez <jdavid.ibp@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Import from itools
from office import MSWord, MSExcel
from ooxml import MSWordX, MSExcelX, MSPowerPointX
from ppt import MSPowerPoint
from rtf import RTF



__all__ = [
    'MSWord',
    'MSExcel',
    'MSPowerPoint',
    'RTF',
    # OOXML
    'MSWordX',
    'MSExcelX',
    'MSPowerPointX',
    ]
